@@ -1,7 +1,8 @@
-/* expert.h
+/** @file
  * Collecting of Expert information.
  *
- * For further info, see: https://wiki.wireshark.org/Development/ExpertInfo
+ * For further info, see:
+ *    https://gitlab.com/wireshark/wireshark/-/wikis/Development/ExpertInfo
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -13,8 +14,8 @@
 #ifndef __EXPERT_H__
 #define __EXPERT_H__
 
-#include <epan/packet_info.h>
 #include <epan/proto.h>
+#include <epan/packet_info.h>
 #include "value_string.h"
 #include "ws_symbol_export.h"
 
@@ -101,8 +102,9 @@ expert_update_comment_count(guint64 count);
         pi is supplied
  @param pi Current protocol item (or NULL)
  @param eiindex The registered expert info item
+ @return the newly created expert info tree
  */
-WS_DLL_PUBLIC void
+WS_DLL_PUBLIC proto_item *
 expert_add_info(packet_info *pinfo, proto_item *pi, expert_field *eiindex);
 
 /** Add an expert info.
@@ -113,8 +115,9 @@ expert_add_info(packet_info *pinfo, proto_item *pi, expert_field *eiindex);
  @param pi Current protocol item (or NULL)
  @param eiindex The registered expert info item
  @param format Printf-style format string for additional arguments
+ @return the newly created expert info tree
  */
-WS_DLL_PUBLIC void
+WS_DLL_PUBLIC proto_item *
 expert_add_info_format(packet_info *pinfo, proto_item *pi, expert_field *eiindex,
                        const char *format, ...) G_GNUC_PRINTF(4, 5);
 
